
#ifndef _C15_ds701_
#define _C15_ds701_

#ifdef __cplusplus
extern "C" {
#endif

extern void F135_1567(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F135_1568(EIF_REFERENCE);
extern void EIF_Minit701(void);
extern long O1519[];
extern long O1513[];

#ifdef __cplusplus
}
#endif

#endif
